@@ -1,8 +1,13 @@
 # frozen_string_literal: true
 
-require 'test_helper'
+require 'fileutils'
 
-class ZipFileTest < MiniTest::Test
+require_relative 'test_helper'
+require_relative 'helpers/assert_entry'
+require_relative 'helpers/common_zipfile_fixtures'
+require_relative 'helpers/zip_entry_data'
+
+class ZipFileTest < Minitest::Test
   include CommonZipFileFixture
   include ZipEntryData
 
@@ -513,7 +518,7 @@ class ZipFileTest < MiniTest::Test
 
   def test_rename_with_each
     zf_name = 'test_rename_zip.zip'
-    ::File.unlink(zf_name) if ::File.exist?(zf_name)
+    FileUtils.rm_f(zf_name)
     arr = []
     arr_renamed = []
     ::Zip::File.open(zf_name, create: true) do |zf|
@@ -537,7 +542,7 @@ class ZipFileTest < MiniTest::Test
     zf = ::Zip::File.open(zf_name)
     assert_equal(zf.entries.map(&:name), arr_renamed)
     zf.close
-    ::File.unlink(zf_name) if ::File.exist?(zf_name)
+    FileUtils.rm_f(zf_name)
   end
 
   def test_rename_to_existing_entry
