@@ -1,8 +1,9 @@
 # frozen_string_literal: true
 
-require 'test_helper'
+require_relative 'test_helper'
+require_relative 'helpers/assert_entry'
 
-class ZipOutputStreamTest < MiniTest::Test
+class ZipOutputStreamTest < Minitest::Test
   include AssertEntry
 
   TEST_ZIP = TestZipFile::TEST_ZIP2.clone
