@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-require 'test_helper'
+require_relative 'test_helper'
 
-class StoredSupportTest < MiniTest::Test
+class StoredSupportTest < Minitest::Test
   STORED_ZIP_TEST_FILE = 'test/data/zipWithStoredCompression.zip'
   ENCRYPTED_STORED_ZIP_TEST_FILE =
     'test/data/zipWithStoredCompressionAndEncryption.zip'
